@@ -165,9 +165,6 @@ class Worker:
 
             result = await asyncio.wait_for(task, job.timeout)
 
-            if self.after_process:
-                await self.after_process(context)
-
             await job.finish(Status.COMPLETE, result=result)
         except asyncio.CancelledError:
             if job:
@@ -182,6 +179,13 @@ class Worker:
                 else:
                     await job.retry(error)
         finally:
+            if (
+                self.after_process
+                and job
+                and job.status in (Status.FAILED, Status.COMPLETE)
+            ):
+                await self.after_process(context)
+
             if monitor and not monitor.done():
                 monitor.cancel()
                 await asyncio.gather(monitor, return_exceptions=True)
@@ -196,7 +200,7 @@ class Worker:
             new_task.add_done_callback(self._process)
 
 
-def start(settings, web=False):
+def start(settings, web=False, port=8080):
     import importlib
 
     # given a.b.c, parses out a.b as the  module path and c as the variable
@@ -219,7 +223,8 @@ def start(settings, web=False):
             await worker.queue.disconnect()
 
         app.on_shutdown.append(shutdown)
+        app["queue"] = worker.queue
         loop.create_task(worker.start())
-        aiohttp.web.run_app(app, loop=loop)
+        aiohttp.web.run_app(app, port=port, loop=loop)
     else:
         loop.run_until_complete(worker.start())
